@@ -4,6 +4,7 @@ from .utilities.tnames import tnames
 from .utilities.time_string import time_string, time_datetime
 from .utilities.time_double import time_float, time_double
 from .utilities.tcopy import tcopy
+from .utilities.tkm2re import tkm2re
 
 from .analysis.avg_data import avg_data
 from .analysis.clean_spikes import clean_spikes
@@ -15,13 +16,22 @@ from .analysis.time_clip import time_clip
 from .analysis.tdeflag import tdeflag
 from .analysis.tdpwrspc import tdpwrspc
 from .analysis.tinterpol import tinterpol
+from .analysis.tnormalize import tnormalize
+from .analysis.tdotp import tdotp
+from .analysis.tcrossp import tcrossp
 from .analysis.tsmooth import tsmooth
 from .analysis.yclip import yclip
+from .analysis.twavpol import twavpol
 from pytplot import cdf_to_tplot
 
+from .cotrans.cotrans import cotrans
+from .cotrans.cotrans_get_coord import cotrans_get_coord
+from .cotrans.cotrans_set_coord import cotrans_set_coord
+
 from .mms import mms_load_mec, mms_load_fgm, mms_load_scm, mms_load_edi, mms_load_edp, mms_load_eis, mms_load_feeps, \
-    mms_load_hpca, mms_load_fpi, mms_load_aspoc, mms_load_dsp, mms_load_fsm
+    mms_load_hpca, mms_load_fpi, mms_load_aspoc, mms_load_dsp, mms_load_fsm, mms_load_state
 from .mms.feeps.mms_feeps_pad import mms_feeps_pad
+from .mms.feeps.mms_feeps_gpd import mms_feeps_gpd
 from .mms.eis.mms_eis_pad import mms_eis_pad
 from .mms.hpca.mms_hpca_calc_anodes import mms_hpca_calc_anodes
 from .mms.hpca.mms_hpca_spin_sum import mms_hpca_spin_sum
@@ -50,3 +60,6 @@ from . import polar
 from . import fast
 from . import equator_s
 from . import solo
+from . import secs
+from . import kyoto
+from . import swarm
